@@ -4,11 +4,13 @@
 import os
 
 application_name = 'toever'
-version = '1.7.0'
+version = '1.8.0'
 
 user_filepath = os.environ['HOME'] + '/.' + application_name
-token_sandbox = False
+sandbox = False
+evernote_url = 'https://www.evernote.com'
 token_geturl = 'https://www.evernote.com/api/DeveloperToken.action'
 
-if token_sandbox:
+if sandbox:
+    evernote_url = 'https://sandbox.evernote.com'
     token_geturl = 'https://sandbox.evernote.com/api/DeveloperToken.action'
